@@ -1,5 +1,5 @@
 test_that("Weighted ITT", {
-  data <- copy(SEQdata)
+  data <- data.table::copy(SEQdata)
   expect_warning(SEQuential(data, "ID", "time", "eligible", "tx_init", "outcome", list("N", "L", "P"), list("sex"),
     method = "ITT",
     options = SEQopts(weighted = TRUE)
@@ -7,7 +7,7 @@ test_that("Weighted ITT", {
 })
 
 test_that("Unexcused Excused Censoring", {
-  data <- copy(SEQdata)
+  data <- data.table::copy(SEQdata)
   expect_warning(SEQuential(data, "ID", "time", "eligible", "tx_init", "outcome", list("N", "L", "P"), list("sex"),
     method = "censoring",
     options = SEQopts(weighted = TRUE, excused = TRUE)
